| Title: | Cubature on the 2-sphere |
|---|---|
| Description: | Cubature methods for numerical integration over the sphere, such as angular averaging over the full solid angle |
| Authors: | Baptiste Auguie [aut, cre] (ORCID: <https://orcid.org/0000-0002-2749-5715>) |
| Maintainer: | Baptiste Auguie <[email protected]> |
| License: | Mozilla Public License Version 2.0 |
| Version: | 0.1.0 |
| Built: | 2026-05-15 05:34:01 UTC |
| Source: | https://github.com/nano-optics/cubs |
Cubature methods for orientation averaging.
Cubature methods for orientation averaging.
baptiste Auguie
cubature points on a sphere
cubs( N = 30, cubature = c("lebedev", "sphericaldesigns", "gl", "fibonacci", "grid", "qmc", "random") )cubs( N = 30, cubature = c("lebedev", "sphericaldesigns", "gl", "fibonacci", "grid", "qmc", "random") )
N |
number of integration points |
cubature |
method: one of 'lebedev', 'sphericaldesigns', 'gl', 'fibonacci', 'grid', 'qmc', 'random' |
Numerical integration points for angular averaging
baptiste Auguie
cubature points on a sphere
is_valid_GL(N) is_valid_grid(N) is_valid_fibonacci(N)is_valid_GL(N) is_valid_grid(N) is_valid_fibonacci(N)
N |
number of integration points |
Tests if a number of points is valid
baptiste Auguie
Nodes and weights of Lebedev cubatures
lebedevlebedev
data.frame with 3 columns
azmuth
polar angle
weight
https://people.sc.fsu.edu/~jburkardt/c_src/sphere_lebedev_rule/sphere_lebedev_rule.html
nodes and weights
nodes and weights
valid numbers
valid numbers
valid numbers
valid numbers
valid numbers
lebedev_table sphericaldesigns_table gl_table grid_table qmc_table random_table fibonacci_tablelebedev_table sphericaldesigns_table gl_table grid_table qmc_table random_table fibonacci_table
data.frame with 2 columns
data.frame with 2 columns
vector
vector
vector
vector
vector
https://people.sc.fsu.edu/~jburkardt/c_src/sphere_lebedev_rule/sphere_lebedev_rule.html
https://people.sc.fsu.edu/~jburkardt/c_src/sphere_lebedev_rule/sphere_lebedev_rule.html
Nodes and weights of spherical t-designs
sphericaldesignssphericaldesigns
data.frame with 3 columns
azmuth
polar angle
weight
https://web.maths.unsw.edu.au/~rsw/Sphere/EffSphDes/